"use strict";

exports.__esModule = true;
exports.getStyleForSettings = exports.getStyleForShadow = exports.getStyleForBackground = exports.getStyleForBorder = exports.getStyleForFormat = exports.getStyleForWidth = exports.getStyleForHeight = exports.getStyleForMargin = exports.getStyleForPadding = exports.getOffetFromUnitValue = void 0;

var _lodash = require("lodash");

var _others = require("./others.util");

var _browsers = require("../definitions/browsers.definition");

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var getOffetFromUnitValue = function getOffetFromUnitValue(value) {
  if ((0, _lodash.isNumber)(value)) {
    return value;
  }

  return value.split(/(px|%|pt|em|[a-z]+)/)[0] || 0;
};

exports.getOffetFromUnitValue = getOffetFromUnitValue;

var getStyleForPadding = function getStyleForPadding(padding, view) {
  if (padding === void 0) {
    padding = {};
  }

  if (view === void 0) {
    view = {};
  }

  return _extends({}, padding);
};

exports.getStyleForPadding = getStyleForPadding;

var getStyleForMargin = function getStyleForMargin(margin, view) {
  if (margin === void 0) {
    margin = {};
  }

  if (view === void 0) {
    view = {};
  }

  return _extends({}, margin);
};

exports.getStyleForMargin = getStyleForMargin;

var getStyleForHeight = function getStyleForHeight(height, view) {
  if (height === void 0) {
    height = {};
  }

  if (view === void 0) {
    view = {};
  }

  return _extends({}, height);
};

exports.getStyleForHeight = getStyleForHeight;

var getStyleForWidth = function getStyleForWidth(width, view) {
  if (width === void 0) {
    width = {};
  }

  if (view === void 0) {
    view = {};
  }

  var style = {};
  var browser = (0, _others.detectBrowser)();

  if ((0, _lodash.isEmpty)(width)) {
    return style;
  }

  if (width.fullWidth) {
    return {
      // width:
      //   browser === BROWSERS.CHROME
      //     ? "-webkit-fill-available"
      //     : browser === BROWSERS.FIREFOX
      //     ? "-moz-available"
      //     : "fill-available",
      width: "100%"
    };
  }

  var custom = getOffetFromUnitValue(width.custom);

  if (custom > view.width) {
    style = {
      width: browser === _browsers.BROWSERS.CHROME ? "-webkit-fill-available" : browser === _browsers.BROWSERS.FIREFOX ? "-moz-available" : "fill-available"
    };
  } else {
    style = {
      width: width.custom
    };
  }

  if (width.autoCenter) {
    style = _extends({}, style, {
      marginLeft: "auto",
      marginRight: "auto"
    });
  }

  return style;
};

exports.getStyleForWidth = getStyleForWidth;

var getStyleForFormat = function getStyleForFormat(format, view) {
  if (format === void 0) {
    format = {};
  }

  if (view === void 0) {
    view = {};
  }

  return _extends({}, getStyleForPadding(format.padding), getStyleForMargin(format.margin), getStyleForHeight(format.height), getStyleForWidth(format.width, view));
};

exports.getStyleForFormat = getStyleForFormat;

var getStyleForBorder = function getStyleForBorder(border, view) {
  if (border === void 0) {
    border = {};
  }

  if (view === void 0) {
    view = {};
  }

  return _extends({}, border);
};

exports.getStyleForBorder = getStyleForBorder;

var getStyleForBackground = function getStyleForBackground(background, view) {
  if (background === void 0) {
    background = {};
  }

  if (view === void 0) {
    view = {};
  }

  return (0, _lodash.isEmpty)(background) ? {} : _extends({
    backgroundColor: background.backgroundColor
  }, (0, _lodash.get)(background, ["backgroundImage", "url"]) ? {
    backgroundImage: "url('" + (0, _lodash.get)(background, ["backgroundImage", "url"]) + "')",
    backgroundPosition: (0, _lodash.get)(background, ["backgroundImage", "position"]) || "center",
    backgroundSize: (0, _lodash.get)(background, ["backgroundImage", "size"]) || "contain"
  } : {});
};

exports.getStyleForBackground = getStyleForBackground;

var getStyleForShadow = function getStyleForShadow(shadow, view) {
  if (shadow === void 0) {
    shadow = {};
  }

  if (view === void 0) {
    view = {};
  }

  return (0, _lodash.isEmpty)(shadow) ? {} : {
    boxShadow: (shadow.horizontal || "0px") + " " + (shadow.vertical || "0px") + " " + (shadow.blur || "0px") + " " + (shadow.spread || "0px") + " " + (shadow.color || "transparent")
  };
};

exports.getStyleForShadow = getStyleForShadow;
var getStyleForSettings = {
  shadow: function shadow(_shadow, view) {
    if (_shadow === void 0) {
      _shadow = {};
    }

    if (view === void 0) {
      view = {};
    }

    return (0, _lodash.isEmpty)(_shadow) ? {} : {
      boxShadow: (_shadow.horizontal || "0px") + " " + (_shadow.vertical || "0px") + " " + (_shadow.blur || "0px") + " " + (_shadow.spread || "0px") + " " + (_shadow.color || "transparent")
    };
  },
  background: function background(_background, view) {
    if (_background === void 0) {
      _background = {};
    }

    if (view === void 0) {
      view = {};
    }

    var style = {};

    if ((0, _lodash.isEmpty)(_background)) {
      return style;
    }

    if ((0, _lodash.hasIn)(_background, "backgroundColor")) {
      style.backgroundColor = _background.backgroundColor;
    }

    if ((0, _lodash.hasIn)(_background, "backgroundImage")) {
      if ((0, _lodash.hasIn)(_background.backgroundImage, "url")) {
        style.backgroundImage = "url('" + (0, _lodash.get)(_background, ["backgroundImage", "url"]) + "')";
      }

      if ((0, _lodash.hasIn)(_background.backgroundImage, "size")) {
        style.backgroundSize = _background.backgroundImage.size;
      }

      if ((0, _lodash.hasIn)(_background.backgroundImage, "position")) {
        style.backgroundPosition = _background.backgroundImage.position;
      }

      if ((0, _lodash.hasIn)(_background.backgroundImage, "repeat")) {
        style.backgroundRepeat = _background.backgroundImage.repeat;
      }
    }

    return style;
  },
  border: function border(_border, view) {
    if (_border === void 0) {
      _border = {};
    }

    if (view === void 0) {
      view = {};
    }

    return _extends({}, _border);
  },
  width: function width(_width, view) {
    if (_width === void 0) {
      _width = {};
    }

    if (view === void 0) {
      view = {};
    }

    var style = {};

    if ((0, _lodash.isEmpty)(_width)) {
      return style;
    }

    if (_width.fullWidth) {
      return {
        width: "100%"
      };
    }

    if (_width.isAuto) {
      return {
        width: "fit-content"
      };
    }

    var custom = getOffetFromUnitValue(_width.custom);

    if (custom > view.width) {
      style = {
        width: "100%"
      };
    } else {
      style = {
        width: _width.custom
      };
    }

    return style;
  },
  height: function height(_height, view) {
    if (_height === void 0) {
      _height = {};
    }

    if (view === void 0) {
      view = {};
    }

    if ("height" in _height) {
      return {
        height: _height.height || "auto"
      };
    } else if ("minHeight" in _height) {
      return {
        minHeight: _height.minHeight || "auto"
      };
    }

    return null;
  },
  padding: function padding(_padding, view) {
    if (_padding === void 0) {
      _padding = {};
    }

    if (view === void 0) {
      view = {};
    }

    return _extends({}, _padding);
  },
  margin: function margin(_margin, view) {
    if (_margin === void 0) {
      _margin = {};
    }

    if (view === void 0) {
      view = {};
    }

    return _extends({}, _margin);
  },
  text: function text(_text, view) {
    if (_text === void 0) {
      _text = {};
    }

    if (view === void 0) {
      view = {};
    }

    var style = {};
    _text.color && (style.color = _text.color);
    _text.size && (style.fontSize = _text.size);
    _text.family && (style.fontFamily = _text.family);
    _text.style && (style.fontStyle = _text.style);
    _text.weight && (style.fontWeight = _text.weight);
    _text.alignment && (style.textAlign = _text.alignment);
    _text.letterSpacing && (style.letterSpacing = _text.letterSpacing);
    _text.lineHeight && (style.lineHeight = _text.lineHeight);
    _text.shadow && (style.textShadow = _text.shadow.horizontal + " " + _text.shadow.vertical + " " + _text.shadow.blur + " " + _text.shadow.color);
    return style;
  },
  contentAlignment: function contentAlignment(_contentAlignment, view) {
    if (_contentAlignment === void 0) {
      _contentAlignment = {};
    }

    if (view === void 0) {
      view = {};
    }

    var style = {};

    if ((0, _lodash.isEmpty)(_contentAlignment)) {
      return style;
    }

    if ((0, _lodash.hasIn)(_contentAlignment, "horizontal")) {
      style.justifyContent = _contentAlignment.horizontal;
    }

    if ((0, _lodash.hasIn)(_contentAlignment, "vertical")) {
      style.alignItems = _contentAlignment.vertical;
    }

    return style;
  },
  alignment: function alignment(_alignment, view) {
    if (_alignment === void 0) {
      _alignment = null;
    }

    if (view === void 0) {
      view = {};
    }

    var style = {};

    if ((0, _lodash.isEmpty)(_alignment)) {
      return style;
    }

    if (_alignment === "left") {
      style.marginRight = "auto";
    }

    if (_alignment === "right") {
      style.marginLeft = "auto";
    }

    if (_alignment === "center") {
      style.marginLeft = "auto";
      style.marginRight = "auto";
    }

    return style;
  },
  addressLevelLabelDisplayLabel: function addressLevelLabelDisplayLabel(display, view) {
    if (view === void 0) {
      view = {};
    }

    return _extends({}, display === true ? {} : display === false ? {
      display: "none"
    } : {});
  },
  optionStyle: function optionStyle(_optionStyle, view, exceptions) {
    if (_optionStyle === void 0) {
      _optionStyle = {};
    }

    if (view === void 0) {
      view = {};
    }

    if (exceptions === void 0) {
      exceptions = [];
    }

    var style = {};

    var _loop = function _loop(key) {
      if (exceptions.some(function (excep) {
        return excep === key;
      })) {
        return "continue";
      }

      if (getStyleForSettings[key]) {
        style = _extends({}, style, getStyleForSettings[key](_optionStyle[key], view));
      }
    };

    for (var key in _optionStyle) {
      var _ret = _loop(key);

      if (_ret === "continue") continue;
    }

    return style; // return getStyleForSettings["text"](optionStyle.text, view);
  },
  selectBoxStyle: function selectBoxStyle(_selectBoxStyle, view, exceptions) {
    if (_selectBoxStyle === void 0) {
      _selectBoxStyle = {};
    }

    if (view === void 0) {
      view = {};
    }

    if (exceptions === void 0) {
      exceptions = [];
    }

    var style = {};

    var _loop2 = function _loop2(key) {
      if (exceptions.some(function (excep) {
        return excep === key;
      })) {
        return "continue";
      }

      if (getStyleForSettings[key]) {
        style = _extends({}, style, getStyleForSettings[key](_selectBoxStyle[key], view));
      }
    };

    for (var key in _selectBoxStyle) {
      var _ret2 = _loop2(key);

      if (_ret2 === "continue") continue;
    }

    return style; // return {
    //   ...getStyleForSettings["border"](selectBoxStyle.border, view),
    //   ...getStyleForSettings["background"](selectBoxStyle.background, view),
    //   ...getStyleForSettings["width"](selectBoxStyle.width, view),
    //   ...getStyleForSettings["text"](selectBoxStyle.text, view),
    // };
  },
  buttonState: function buttonState(stateStyle, view, exceptions) {
    if (stateStyle === void 0) {
      stateStyle = {};
    }

    if (view === void 0) {
      view = {};
    }

    if (exceptions === void 0) {
      exceptions = [];
    }

    return _extends({}, getStyleForSettings["text"](stateStyle.text, view), getStyleForSettings["border"](stateStyle.border, view), getStyleForSettings["shadow"](stateStyle.shadow, view), getStyleForSettings["background"](stateStyle.background, view));
  },
  styleGroups: function styleGroups(groups, view, exceptions) {
    if (groups === void 0) {
      groups = {};
    }

    if (view === void 0) {
      view = {};
    }

    if (exceptions === void 0) {
      exceptions = [];
    }

    var style = {};

    var _loop3 = function _loop3(key) {
      if (exceptions.some(function (excep) {
        return excep === key;
      })) {
        return "continue";
      }

      if (getStyleForSettings[key]) {
        style = _extends({}, style, getStyleForSettings[key](groups[key], view));
      }
    };

    for (var key in groups) {
      var _ret3 = _loop3(key);

      if (_ret3 === "continue") continue;
    }

    return style;
  }
};
exports.getStyleForSettings = getStyleForSettings;